@@ -1,3 +1,9 @@
+try:
+    import tensorflow as tf
+    TF_ENABLED = True
+except ImportError:
+    TF_ENABLED = False
+
 from graphgallery.backend import *
 from graphgallery.data_type import *
 
@@ -14,7 +20,6 @@ from graphgallery import attack
 
 from .version import __version__
 
-__all__ = [
-    "graphgallery", "nn", "gallery", "utils", "sequence", "data", "datasets",
-    "backend", "functional", "attack", "__version__"
-]
+__all__ = ["nn", "gallery", "utils", "sequence", "data", "datasets",
+           "backend", "functional", "attack", "__version__"
+           ]
