@@ -1,5 +1,5 @@
-from .gpu import *
+from .memory import *
 from .modules import *
 from .backend import *
 from .config import *
-from .regist import *
+from .registry import *
