@@ -1,5 +1,4 @@
 # Copyright (c) Facebook, Inc. and its affiliates. All Rights Reserved.
-import logging
 import os
 import warnings
 from typing import IO, Any, Callable, Dict, List, Union
@@ -122,8 +121,27 @@ class CfgNode(_CfgNode):
 
 
 def merge_dict(a, b):
+    """merge dict instance b into a,
+        an extended version of `update` method.
+
+    Examples
+    --------
+    >>> a = {'x': 1,  'y': {'z': 2, 'v': 3}}
+    >>> b = {'y': {'z': 3}}
+    >>> a.update(ab)
+    {'x': 1,  'y': {'z': 3}}
+    >>> merge_dict(a,b)
+    {'x': 1,  'y': {'z': 3, 'v': 3}}
+
+    Parameters
+    ----------
+    a : dict
+    b : dict
+    """
     for k, v in b.items():
         if not isinstance(v, dict):
             a[k] = v
         else:
+            if k not in a:
+                a[k] = CfgNode()
             merge_dict(a[k], b[k])
