@@ -1,80 +1,93 @@
+import sys
 import torch
-import tensorflow
-import numpy
-
+import importlib
 
 __all__ = ['BackendModule', 'TensorFlowBackend',
-           'PyTorchBackend', 'PyGBackend', 'DGLPyTorchBackend', 'DGLTensorFlowBackend']
+           'PyTorchBackend', 'PyGBackend',
+           'DGLBackend']
 
 
 class BackendModule:
     """Base Backend Module Class."""
 
-    alias = {}
+    alias = set()
 
-    def __init__(self):
+    def __init__(self, module=None):
         self.acceptable_names = self.alias
 
+        if module is not None:
+            try:
+                self.module = importlib.import_module(module)
+            except ImportError as e:
+                print(f"Something went wrong when import `{module}`.", file=sys.stderr)
+                raise e
+        else:
+            self.module = None
+
     @property
-    def version(self) -> str:
+    def version(self):
         raise NotImplementedError
 
     @property
-    def name(self) -> str:
+    def name(self):
         raise NotImplementedError
 
     @property
-    def abbr(self) -> str:
+    def abbr(self):
+        # used for specifying the module
         return NotImplementedError
 
     def __eq__(self, value) -> bool:
         return str(value).lower() in self.acceptable_names
 
-    def __repr__(self) -> str:
+    def __repr__(self):
         return f"{self.name} {self.extra_repr()} Backend"
     __str__ = __repr__
 
     def extra_repr(self):
         return self.version
 
+    def device(self, ctx):
+        return self.module.device(ctx)
+
 
 class PyTorchBackend(BackendModule):
     alias = {"th", "torch", "pytorch"}
 
-    def __init__(self):
-        super().__init__()
+    def __init__(self, module='torch'):
+        super().__init__(module=module)
         self.acceptable_names = self.acceptable_names.union({"pth", "th", "torch", "pytorch"})
 
     @property
-    def version(self) -> str:
-        return torch.__version__
+    def version(self):
+        return self.module.__version__
 
     @property
-    def name(self) -> str:
+    def name(self):
         return "PyTorch"
 
     @property
-    def abbr(self) -> str:
+    def abbr(self):
         return "pytorch"
 
 
 class TensorFlowBackend(BackendModule):
     alias = {"tf", "tensorflow"}
 
-    def __init__(self):
-        super().__init__()
+    def __init__(self, module='tensorflow'):
+        super().__init__(module=module)
         self.acceptable_names = self.acceptable_names.union({"tf", "tensorflow"})
 
     @property
-    def version(self) -> str:
-        return tensorflow.__version__
+    def version(self):
+        return self.module.__version__
 
     @property
-    def name(self) -> str:
+    def name(self):
         return "TensorFlow"
 
     @property
-    def abbr(self) -> str:
+    def abbr(self):
         return "tensorflow"
 
 
@@ -82,70 +95,49 @@ class PyGBackend(PyTorchBackend):
     alias = {"pyg"}
 
     def __init__(self):
-        super().__init__()
+        super().__init__(module='torch_geometric')
         self.acceptable_names = self.acceptable_names.union({"pyg"})
 
     @property
-    def version(self) -> str:
-        import torch_geometric
-        return torch_geometric.__version__
+    def version(self):
+        return self.module.__version__
 
     @property
-    def name(self) -> str:
+    def name(self):
         return "PyTorch Geometric"
 
     @property
-    def abbr(self) -> str:
+    def abbr(self):
         return "pyg"
 
     def extra_repr(self):
         return f"{super().extra_repr()} (PyTorch {torch.__version__})"
 
-
-class DGLTensorFlowBackend(TensorFlowBackend):
-
-    alias = {"dgl_tf"}
-
-    def __init__(self):
-        super().__init__()
-        self.acceptable_names = self.acceptable_names.union({"dgl_tf"})
-
-    @property
-    def version(self) -> str:
-        import dgl
-        return dgl.__version__
-
-    @property
-    def name(self) -> str:
-        return "DGL TensorFlow"
-
-    @property
-    def abbr(self) -> str:
-        return "dgl_tf"
-
-    def extra_repr(self):
-        return f"{super().extra_repr()} (TensorFlow {tensorflow.__version__})"
+    def device(self, ctx):
+        return torch.device(ctx)
 
 
-class DGLPyTorchBackend(PyTorchBackend):
+class DGLBackend(PyTorchBackend):
     alias = {"dgl_torch", "dgl_th", "dgl"}
 
     def __init__(self):
-        super().__init__()
+        super().__init__(module='dgl')
         self.acceptable_names = self.acceptable_names.union({"dgl_torch", "dgl_th", "dgl"})
 
     @property
-    def version(self) -> str:
-        import dgl
-        return dgl.__version__
+    def version(self):
+        return self.module.__version__
 
     @property
-    def name(self) -> str:
+    def name(self):
         return "DGL PyTorch"
 
     @property
-    def abbr(self) -> str:
-        return "dgl_torch"
+    def abbr(self):
+        return "dgl"
 
     def extra_repr(self):
         return f"{super().extra_repr()} (PyTorch {torch.__version__})"
+
+    def device(self, ctx):
+        return torch.device(ctx)
