@@ -3,7 +3,6 @@ import numpy as np
 import os.path as osp
 from functools import partial
 from copy import copy as _copy, deepcopy as _deepcopy
-from typing import Union, Tuple, List
 
 from .apply import check_and_convert, sparse_apply
 from .io import load_npz
@@ -12,12 +11,12 @@ from .io import load_npz
 class BaseGraph:
     multiple = None
 
-    def __init__(self, *args, **kwargs):
+    def __init__(self, **kwargs):
         kwargs.pop('__class__', None)
         self.update(**kwargs)
 
     @property
-    def num_nodes(self) -> int:
+    def num_nodes(self):
         """Get the number of nodes in the graph."""
         raise NotImplementedError
 
@@ -29,57 +28,67 @@ class BaseGraph:
         raise NotImplementedError
 
     @property
-    def num_graphs(self) -> int:
+    def num_graphs(self):
         """Get the number of graphs."""
         raise NotImplementedError
 
     @property
-    def num_node_attrs(self) -> int:
+    def num_node_attrs(self):
         """Get the number of attribute dimensions of the nodes."""
         raise NotImplementedError
 
     @property
-    def num_edge_attrs(self) -> int:
+    def num_edge_attrs(self):
         """Get the number of attribute dimensions of the edges."""
         raise NotImplementedError
 
     @property
-    def num_graph_attrs(self) -> int:
+    def num_graph_attrs(self):
         """Get the number of attribute dimensions of the graphs."""
         raise NotImplementedError
 
     @property
-    def num_node_classes(self) -> int:
+    def num_node_classes(self):
         """Get the number of node classes."""
         raise NotImplementedError
 
     @property
-    def num_edge_classes(self) -> int:
+    def num_edge_classes(self):
         """Get the number of edge classes."""
         raise NotImplementedError
 
     @property
-    def num_graph_classes(self) -> int:
+    def num_graph_classes(self):
         """Get the number of graph classes."""
         raise NotImplementedError
 
-    def is_node_attributed(self) -> bool:
-        return hasattr(self, "node_attr") and self.node_attr is not None
+    def is_node_attributed(self):
+        """Whether the graph has node attributes"""
+        return getattr(self, "node_attr", None)
 
-    def is_edge_attributed(self) -> bool:
-        return hasattr(self, "edge_attr") and self.edge_attr is not None
+    def is_edge_attributed(self):
+        """Whether the graph has edge attributes"""
+        return getattr(self, "edge_attr", None)
 
-    def is_graph_attributed(self) -> bool:
-        return hasattr(self, "graph_attr") and self.graph_attr is not None
+    def is_graph_attributed(self):
+        """Whether the graph has graph attributes (for multiple graph)"""
+        return getattr(self, "graph_attr", None)
 
-    def is_node_labeled(self) -> bool:
-        return hasattr(self, "node_label") and self.node_label is not None
+    def is_node_labeled(self):
+        """Whether the graph has node labels"""
+        return getattr(self, "node_label", None)
 
-    def is_edge_labeled(self) -> bool:
-        return hasattr(self, "edge_label") and self.edge_label is not None
+    def is_edge_labeled(self):
+        """Whether the graph has edge labels"""
+        return getattr(self, "edge_label", None)
 
-    def is_graph_labeled(self) -> bool:
-        return hasattr(self, "graph_label") and self.graph_label is not None
+    def is_graph_labeled(self):
+        """Whether the graph has graph labels (for multiple graph)"""
+        return getattr(self, "graph_label", None)
+    
+    def is_multiple(self):
+        """Whether the graph is a multiple graph instance"""
+        return self.multiple
 
     def keys(self):
         # maybe using `tuple`?
@@ -108,14 +117,34 @@ class BaseGraph:
         filepath = osp.abspath(osp.expanduser(filepath))
         loader = load_npz(filepath)
         loader.pop("__class__", None)
-        print(f"Loading from {filepath}", file=sys.stderr)
+        loader.pop("multiple", None)
+#         print(f"Loading from {filepath}", file=sys.stderr)
         return cls(copy=False, **loader)
 
     def to_npz(self, filepath: str, apply_fn=sparse_apply, compressed=True):
+        """save the graph to NPZ files
 
+        Parameters
+        ----------
+        filepath : str
+            the path where the graph will be saved.
+        apply_fn :  callable, optional
+            the apply function for each items in the graph, by default `sparse_apply`,
+            i.e., the matrix will be saved as scipy sparse matrix for efficiency
+            if it is sparse enough
+        compressed : bool, optional
+            if True, use `np.savez_compressed` function to save,
+            else use `np.savez`, by default True
+
+        Returns
+        -------
+        str
+            the filepath where the graph is saved.
+        """
         filepath = osp.abspath(osp.expanduser(filepath))
         data_dict = {k: v for k, v in self.items(apply_fn=apply_fn) if v is not None}
         data_dict["__class__"] = str(self.__class__.__name__)
+        data_dict["multiple"] = self.multiple
         if compressed:
             save_fn = np.savez_compressed
         else:
@@ -126,6 +155,18 @@ class BaseGraph:
         return filepath
 
     def update(self, *, apply_fn=None, copy=False, **collects):
+        """Update the items in the graph
+
+        Parameters
+        ----------
+        apply_fn : callable, optional
+            callable function which applied to the update items, by default None,
+            and it will use `check_and_convert` function to check if it is allowed and
+            convert to proper types.
+        copy : bool, optional
+            whether to use copy of the value, by default False for efficiency.
+            Note that the value will be changed if donot use copy.
+        """
         if apply_fn is None:
             apply_fn = partial(check_and_convert,
                                multiple=self.multiple,
@@ -154,8 +195,8 @@ class BaseGraph:
         for key in keys:
             yield getattr(self, key, None)
 
-    def __dir__(self):
-        return self.keys()
+    # def __dir__(self):
+    #     return self.keys()
 
     def __copy__(self):
         cls = self.__class__
