@@ -7,7 +7,6 @@ from typing import Union, Optional, List, Tuple, Any, Callable
 from graphgallery import functional as gf
 
 from .base_graph import BaseGraph
-from .preprocess import create_subgraph
 from .utils import *
 
 
@@ -65,44 +64,38 @@ class HomoGraph(BaseGraph):
 
     @property
     def num_nodes(self) -> int:
-        """Get the number of nodes in the graph."""
         return get_num_nodes(self.adj_matrix)
 
     @property
     def num_edges(self) -> int:
-        """Get the number of edges in the graph.
-        For undirected graphs, (i, j) and (j, i) are counted as single edge.
-        """
         return get_num_edges(self.adj_matrix, self.is_directed())
+
     @property
     def density(self) -> float:
         """Get the density of the graph.
         It is defined as M/(N x N)
         where M is number of edges and N is number of nodes
-        """        
-        return self.num_edges/self.num_nodes**2
-    
+        """
+        return self.num_edges / self.num_nodes**2
+
     @property
     def sparsity(self) -> float:
         """Get the sparsity of the graph.
         It is defined as 1 - M/(N x N)
         where M is number of edges and N is number of nodes
-        """        
+        """
         return 1.0 - self.density
-    
+
     @property
     def num_graphs(self) -> int:
-        """Get the number of graphs."""
         return get_num_graphs(self.adj_matrix)
 
     @property
     def num_node_attrs(self) -> int:
-        """Get the number of attribute dimensions of the nodes."""
         return get_num_node_attrs(self.node_attr)
 
     @property
     def num_node_classes(self) -> int:
-        """Get the number of classes node_label of the nodes."""
         return get_num_node_classes(self.node_label)
 
     @property
@@ -157,7 +150,7 @@ class HomoGraph(BaseGraph):
 
     @property
     def degree(self):
-        return get_degree(self.adj_matrix)
+        return gf.degree(self.adj_matrix)
 
     def eliminate_selfloops(self):
         """Remove self-loops from the adjacency matrix."""
@@ -176,31 +169,31 @@ class HomoGraph(BaseGraph):
 
     def is_directed(self) -> bool:
         """Check if the graph is directed (adjacency matrix is not symmetric)."""
-        return is_directed(self.adj_matrix)
+        return gf.is_directed(self.adj_matrix)
 
     def has_singleton(self) -> bool:
         """Check if the graph has singletons."""
-        return has_singleton(self.adj_matrix)
+        return gf.has_singleton(self.adj_matrix)
 
     def has_selfloops(self) -> bool:
         """Check if the graph has self loops."""
-        return has_selfloops(self.adj_matrix)
+        return gf.has_selfloops(self.adj_matrix)
 
     def is_connected(self) -> bool:
         """Check if the graph is a connected graph."""
-        return is_connected(self.adj_matrix)
+        return gf.is_connected(self.adj_matrix)
 
     def is_weighted(self) -> bool:
         """Check if the graph is weighted (edge weights other than 1)."""
-        return is_weighted(self.adj_matrix)
+        return gf.is_weighted(self.adj_matrix)
 
     def is_symmetric(self) -> bool:
         """Check if the adjacency matrix is symmetric."""
-        return is_symmetric(self.adj_matrix)
+        return gf.is_symmetric(self.adj_matrix)
 
     def is_binary(self) -> bool:
         """Check if the node attribute matrix has binary attributes."""
-        return is_binary(self.node_attr)
+        return gf.is_binary(self.node_attr)
 
     def extra_repr(self) -> str:
         excluded = {"metadata", "mapping"}
