@@ -5,114 +5,35 @@ import scipy.sparse as sp
 import pickle as pkl
 
 from typing import Optional, List, Tuple, Union
-from collections import Counter
 from sklearn.preprocessing import MultiLabelBinarizer, LabelBinarizer, normalize
 from sklearn.model_selection import train_test_split
 
 
-def train_val_test_split_tabular(N: int,
-                                 train_size: float = 0.1,
-                                 val_size: float = 0.1,
-                                 test_size: float = 0.8,
+def train_val_test_split_tabular(N: int, *,
+                                 train: float = 0.1,
+                                 test: float = 0.8,
+                                 val: float = 0.1,
                                  stratify=None,
                                  random_state: Optional[int] = None):
 
     idx = np.arange(N)
-    idx_train_and_val, idx_test = train_test_split(idx,
-                                                   random_state=random_state,
-                                                   train_size=(
-                                                       train_size + val_size),
-                                                   test_size=test_size,
-                                                   stratify=stratify)
-
-    stratify = stratify[idx_train_and_val]
-    idx_train, idx_val = train_test_split(idx_train_and_val,
-                                          random_state=random_state,
-                                          train_size=(
-                                              train_size / (train_size + val_size)),
-                                          test_size=(
-                                              val_size / (train_size + val_size)),
-                                          stratify=stratify)
+    idx_train, idx_test = train_test_split(idx,
+                                           random_state=random_state,
+                                           train_size=train + val,
+                                           test_size=test,
+                                           stratify=stratify)
+    if val:
+        stratify = stratify[idx_train]
+        idx_train, idx_val = train_test_split(idx_train,
+                                              random_state=random_state,
+                                              train_size=train / (train + val),
+                                              stratify=stratify)
+    else:
+        idx_val = None
 
     return idx_train, idx_val, idx_test
 
 
-def largest_connected_components(graph: "Graph") -> "Graph":
-    """Select the largest connected components in the graph.
-
-    Parameters
-    ----------
-    graph : Graph
-        Input graph.
-
-    Returns
-    -------
-    graph : Graph
-        Subgraph of the input graph where only the nodes in largest num_components are kept.
-    """
-    _, component_indices = sp.csgraph.connected_components(graph.adj_matrix)
-    component_sizes = np.bincount(component_indices)
-    components_to_keep = np.argsort(component_sizes)[-1]
-    nodes_to_keep = np.where(component_indices == components_to_keep)[0]
-    return create_subgraph(graph, nodes_to_keep=nodes_to_keep)
-
-
-def create_subgraph(graph: "Graph", *,
-                    nodes_to_remove=None,
-                    nodes_to_keep=None) -> "Graph":
-    r"""Create a graph with the specified subset of nodes.
-    Exactly one of (nodes_to_remove, nodes_to_keep) should be provided, while the other stays None.
-    Note that to avoid confusion, it is required to pass node indices as named Parameters to this function.
-
-    Parameters
-    ----------
-    graph : Graph
-        Input graph.
-    nodes_to_remove : array-like of int
-        Indices of nodes that have to removed.
-    nodes_to_keep : array-like of int
-        Indices of nodes that have to be kept.
-
-    Returns
-    -------
-    graph : Graph
-        Graph with specified nodes removed.
-    """
-    # Check that Parameters are passed correctly
-    if nodes_to_remove is None and nodes_to_keep is None:
-        raise ValueError(
-            "Either nodes_to_remove or nodes_to_keep must be provided.")
-    elif nodes_to_remove is not None and nodes_to_keep is not None:
-        raise ValueError(
-            "Only one of nodes_to_remove or nodes_to_keep must be provided.")
-    elif nodes_to_remove is not None:
-        if len(nodes_to_remove) == 0:
-            return graph.copy()
-        nodes_to_keep = np.setdiff1d(np.arange(graph.num_nodes), nodes_to_remove)
-    elif nodes_to_keep is not None:
-        nodes_to_keep = np.sort(nodes_to_keep)
-    else:
-        raise RuntimeError("This should never happen.")
-    # TODO: multiple graph
-    graph = graph.copy()
-
-    adj_matrix, node_attr, node_label = graph('adj_matrix',
-                                              'node_attr',
-                                              'node_label')
-    graph.adj_matrix = adj_matrix[nodes_to_keep][:, nodes_to_keep]
-    if node_attr is not None:
-        graph.node_attr = node_attr[nodes_to_keep]
-    if node_label is not None:
-        graph.node_label = node_label[nodes_to_keep]
-
-    # TODO: remove?
-    metadata = copy.deepcopy(graph.metadata)
-    if metadata is not None and 'node_names' in metadata:
-        graph.metadata['node_names'] = metadata['node_names'][nodes_to_keep]
-
-    return graph
-
-
 def binarize_labels(labels, sparse_output: bool = False, returnum_node_classes: bool = False):
     """Convert labels vector to a binary label matrix.
     In the default single-label case, labels look like
@@ -147,6 +68,50 @@ def binarize_labels(labels, sparse_output: bool = False, returnum_node_classes:
     return (label_matrix, binarizer.classes_) if returnum_node_classes else label_matrix
 
 
+def get_train_val_test_split_gcn(labels, num_samples=20, random_state=None):
+    """This setting follows gcn, where we randomly sample 'num_samples' instances for each class as training data, 500 instances as validation data, 1000 instances as test data.
+
+    Note here we are not using fixed splits. When random_state changes, the splits ofwill also change.
+
+    Parameters
+    ----------
+    labels : numpy.array
+        node labels
+    num_samples: int
+        the number of samples of each class for training
+    random_state : int or None
+        random random_state
+
+    Returns
+    -------
+    idx_train :
+        node training indices
+    idx_val :
+        node validation indices
+    idx_test :
+        node test indices
+    """
+    if random_state is not None:
+        np.random.seed(random_state)
+
+    idx = np.arange(len(labels))
+    nclass = labels.max() + 1
+    idx_train = []
+    idx_unlabeled = []
+    for i in range(nclass):
+        labels_i = idx[labels == i]
+        labels_i = np.random.permutation(labels_i)
+        idx_train.append(labels_i[:num_samples])
+        idx_unlabeled.append(labels_i[num_samples:])
+
+    idx_train = np.hstack(idx_train)
+    idx_unlabeled = np.hstack(idx_unlabeled)
+    idx_unlabeled = np.random.permutation(idx_unlabeled)
+    idx_val = idx_unlabeled[: 500]
+    idx_test = idx_unlabeled[500: 1500]
+    return idx_train, idx_val, idx_test
+
+
 def get_train_val_test_split(stratify,
                              trainum_examples_per_class: int,
                              val_examples_per_class: int,
@@ -240,6 +205,17 @@ def process_planetoid_datasets(name: str, paths: List[str]) -> Tuple:
         ty_extended[test_idx_range - min(test_idx_range), :] = ty
         ty = ty_extended
 
+    elif 'nell.0' in name.lower():
+        # Find relation nodes, add them as zero-vecs into the right position
+        test_idx_range_full = np.arange(allx.shape[0], len(graph))
+        isolated_node_idx = np.setdiff1d(test_idx_range_full, test_idx_reorder)
+        tx_extended = sp.lil_matrix((len(test_idx_range_full), x.shape[1]))
+        tx_extended[test_idx_range - allx.shape[0], :] = tx
+        tx = tx_extended
+        ty_extended = np.zeros((len(test_idx_range_full), y.shape[1]))
+        ty_extended[test_idx_range - allx.shape[0], :] = ty
+        ty = ty_extended
+
     node_attr = sp.vstack((allx, tx)).tolil()
     node_attr[test_idx_reorder, :] = node_attr[test_idx_range, :]
 
