@@ -5,3 +5,5 @@ from .npz_dataset import NPZDataset
 from .ppi import PPI
 from .reddit import Reddit
 from .tu_dataset import TUDataset
+from .karateclub import KarateClub
+from .musae import MUSAE
