@@ -1,35 +1,32 @@
-import os
 import sys
-import zipfile
 import os.path as osp
-import numpy as np
 
-from typing import Optional, List, Tuple, Union, Callable
+from typing import List
 from .in_memory_dataset import InMemoryDataset
-from ..data.io import makedirs, files_exist, download_file
-from ..data.graph import Graph
+from ..data.io import makedirs, download_file, load_npz
+from ..data import Graph, EdgeGraph, MultiGraph, MultiEdgeGraph
 
 _DATASETS = {
     'citeseer', 'citeseer_full', 'cora', 'cora_ml', 'cora_full', 'amazon_cs',
     'amazon_photo', 'coauthor_cs', 'coauthor_phy', 'polblogs', 'karate_club',
-    'pubmed', 'flickr', 'blogcatalog', 'dblp', 'acm', 'uai'
+    'pubmed', 'flickr', 'blogcatalog', 'dblp', 'acm', 'uai', 'pdn',
 }
 
 _DATASET_URL = "https://github.com/EdisonLeeeee/GraphData/raw/master/datasets"
 
-Transform = Union[List, Tuple, str, List, Tuple, Callable]
-
 
 class NPZDataset(InMemoryDataset):
 
-    _url = _DATASET_URL
+    __url__ = _DATASET_URL
 
     def __init__(self,
-                 name: str,
-                 root: Optional[str] = None,
-                 url: Optional[str] = None,
-                 transform: Optional[Transform] = None,
-                 verbose: bool = True):
+                 name,
+                 root=None,
+                 *,
+                 transform=None,
+                 verbose=True,
+                 url=None,
+                 remove_download=False):
 
         name = str(name)
         if not name in self.available_datasets():
@@ -39,14 +36,16 @@ class NPZDataset(InMemoryDataset):
             self.custom = True
         else:
             self.custom = False
-
-        super().__init__(name, root, url, transform, verbose)
+        super().__init__(name=name, root=root,
+                         transform=transform,
+                         verbose=verbose, url=url,
+                         remove_download=remove_download)
 
     @staticmethod
     def available_datasets():
         return _DATASETS
 
-    def _download(self) -> None:
+    def __download__(self) -> None:
         if not self.custom:
             makedirs(self.download_dir)
             download_file(self.download_paths, self.urls)
@@ -60,17 +59,16 @@ class NPZDataset(InMemoryDataset):
     def download_dir(self):
         return self.root
 
-    def _process(self) -> dict:
-        graph = Graph.from_npz(self.raw_paths[0])
+    def __process__(self) -> dict:
+        loader = load_npz(self.raw_paths[0])
+        graph_cls = loader.pop("__class__", "Graph")
+        assert graph_cls in {"Graph", "MultiGraph", "EdgeGraph", "MultiEdgeGraph"}, graph_cls
+        graph = eval(graph_cls).from_npz(self.raw_paths[0])
         return dict(graph=graph)
 
-    @property
-    def processed_path(self) -> str:
-        return None
-
     @property
     def url(self) -> str:
-        return f'{self._url}/{self.name}.npz'
+        return f'{self.__url__}/{self.name}.npz'
 
     @property
     def raw_paths(self) -> List[str]:
