@@ -1,12 +1,16 @@
-from .bunchdict import BunchDict
-from .registry import Registry
-from .transforms import *
-from .decorators import *
+# modules
 from .functions import *
 from .edge_level import *
 from .sparse import *
 from .dense import *
 from .graph_level import *
-from .get_transform import *
+from .network import *
+
+# functions
+from .bunchdict import BunchDict
+from .registry import Registry
+from .base_transforms import *
+from .decorators import *
+from .transform import *
 from .tensor import *
 from .random import random_seed
