@@ -6,7 +6,7 @@ class BunchDict(OrderedDict):
     """Container object for datasets
     Dictionary-like object that exposes its keys as attributes
     and remembers insertion order.
-    >>> b = Bunch(a=1, b=2)
+    >>> b = BunchDict(a=1, b=2)
     >>> b['b']
     2
     >>> b.b
@@ -53,9 +53,11 @@ def prettify(item):
         else:
             val = f"{val.__class__.__name__}, shape={val.shape}"
     else:
-        try:
-            val = f"{type(val).__name__}, len={len(val)}"
-        except TypeError:
-            pass
-
+        if isinstance(val, str):
+            val = f"{val}"
+        else:
+            try:
+                val = f"{type(val).__name__}, len={len(val)}"
+            except TypeError:
+                pass
     return key, val
