@@ -3,3 +3,5 @@ from .flip import *
 from .onehot import *
 from .node_sim import knn_graph, attr_sim
 from .similarity import *
+from .erase import *
+from .activations import *
