@@ -1,25 +1,22 @@
 import numpy as np
 
-from ..transforms import Transform
+from ..base_transforms import DenseTransform
 from ..decorators import multiple
-from ..get_transform import Transformers
+from ..transform import Transform
 
 __all__ = ['onehot', 'Onehot']
 
 
-@Transformers.register()
-class Onehot(Transform):
+@Transform.register()
+class Onehot(DenseTransform):
 
     def __init__(self, depth=None):
         super().__init__()
-        self.depth = depth
+        self.collect(locals())
 
     def __call__(self, *x):
         return onehot(*x, depth=self.depth)
 
-    def extra_repr(self):
-        return f"depth={self.depth}"
-
 
 @multiple()
 def onehot(label, depth=None):
