@@ -2,19 +2,16 @@ import torch
 import itertools
 
 import numpy as np
-import networkx as nx
-import tensorflow as tf
 import scipy.sparse as sp
 
 from typing import Any, Optional
-from numbers import Number
 
 import graphgallery as gg
 from graphgallery import functional as gf
 
 __all__ = ['asarray', 'index_to_mask',
            'repeat', 'get_length',
-           'nx_graph_to_sparse_adj', 
+           'nx_graph_to_sparse_adj',
            'largest_indices', 'least_indices']
 
 
@@ -34,8 +31,9 @@ def asarray(x: Any, dtype: Optional[str] = None) -> np.ndarray:
     if dtype is None:
         dtype = gg.intx()
 
-    if gf.is_tensor(x, backend="tensorflow"):
+    if gg.TF_ENABLED and gf.is_tensor(x, backend="tensorflow"):
         if x.dtype != dtype:
+            import tensorflow as tf
             return tf.cast(x, dtype=dtype)
         else:
             return x
@@ -62,7 +60,7 @@ def index_to_mask(indices: np.ndarray, shape: tuple) -> np.ndarray:
     return mask
 
 
-def repeat(src: Any, length: int=None) -> Any:
+def repeat(src: Any, length: int = None) -> Any:
     if src == [] or src == ():
         return []
     if length is None:
@@ -95,10 +93,14 @@ def nx_graph_to_sparse_adj(graph):
 
 def largest_indices(array: np.ndarray, n: int) -> tuple:
     """Returns the n largest indices from a numpy array.
-    Arguments:
+
+    Parameters:
+    ----------
         array {np.ndarray} -- data array
         n {int} -- number of elements to select
+
     Returns:
+    --------
         tuple[np.ndarray] -- tuple of ndarray
         each ndarray is index
     """
@@ -110,10 +112,14 @@ def largest_indices(array: np.ndarray, n: int) -> tuple:
 
 def least_indices(array: np.ndarray, n: int) -> tuple:
     """Returns the n least indices from a numpy array.
-    Arguments:
+
+    Parameters:
+    ----------
         array {np.ndarray} -- data array
         n {int} -- number of elements to select
+
     Returns:
+    --------
         tuple[np.ndarray] -- tuple of ndarray
         each ndarray is index
     """
@@ -121,4 +127,3 @@ def least_indices(array: np.ndarray, n: int) -> tuple:
     indices = np.argpartition(flat, n)[:n]
     indices = indices[np.argsort(flat[indices])]
     return np.unravel_index(indices, array.shape)
-
