@@ -2,3 +2,5 @@ from .generate_attr import *
 from .standardize import *
 from .purification import *
 from .graph_partition import GraphPartition, graph_partition
+from .subgraph import subgraph
+from .dict_transform import DictTransform
