@@ -1,7 +1,12 @@
+
 try:
     import metis
 except ImportError:
     metis = None
+    WARNING_MSG = "The metis Python interface is not installed, try `pip install metis`. See <http://glaros.dtc.umn.edu/gkhome/metis/metis/overview> for more details."
+except RuntimeError:
+    metis = None
+    WARNING_MSG = "The metis toolkit is not installed, try `sudo apt-get install libmetis-dev` (for Ubuntu only). See <http://glaros.dtc.umn.edu/gkhome/metis/metis/overview> for more details."
 
 import numpy as np
 import networkx as nx
@@ -9,8 +14,8 @@ import scipy.sparse as sp
 from scipy.sparse.csgraph import connected_components
 from graphgallery import intx
 
-from ..transforms import Transform
-from ..get_transform import Transformers
+from ..base_transforms import GraphTransform
+from ..transform import Transform
 
 
 def metis_clustering(graph, num_clusters):
@@ -25,18 +30,15 @@ def random_clustering(num_nodes, num_clusters):
     return parts
 
 
-@Transformers.register()
-class GraphPartition(Transform):
+@Transform.register()
+class GraphPartition(GraphTransform):
     def __init__(self, num_clusters: int = None, metis_partition: bool = True):
-        self.num_clusters = num_clusters
-        self.metis_partition = metis_partition
+        super().__init__()
+        self.collect(locals())
 
     def __call__(self, graph):
         return graph_partition(graph, num_clusters=self.num_clusters, metis_partition=self.metis_partition)
 
-    def extra_repr(self):
-        return f"num_clusters={self.num_clusters}, metis_partition={self.metis_partition}"
-
 
 # TODO: accept a Graph and output a MultiGraph
 def graph_partition(graph, num_clusters: int = None, metis_partition: bool = True):
@@ -46,7 +48,8 @@ def graph_partition(graph, num_clusters: int = None, metis_partition: bool = Tru
         num_clusters = graph.num_node_classes
     # partition graph
     if metis_partition:
-        assert metis, "Please install `metis` package!"
+
+        assert metis, WARNING_MSG
         parts = metis_clustering(graph.nxgraph(), num_clusters)
     else:
         parts = random_clustering(adj_matrix.shape[0], num_clusters)
