@@ -2,8 +2,8 @@ import warnings
 import numpy as np
 import scipy.sparse as sp
 
-from ..transforms import Transform
-from ..get_transform import Transformers
+from ..base_transforms import GraphTransform
+from ..transform import Transform
 from ..edge_level import singleton_filter
 from ..sparse import remove_edge
 import graphgallery as gg
@@ -23,6 +23,12 @@ def cosine_similarity(A, B):
     C = inner_product / (np.sqrt(np.square(A).sum(1)) * np.sqrt(np.square(B).sum(1)) + gg.epsilon())
     return C
 
+# Using PyTorch
+# def cosine_similarity(A, B):
+#     inner_product = (A * B).sum(1)
+#     C = inner_product / (torch.norm(A, 2, 1) * torch.norm(B, 2, 1) + 1e-7)
+#     return C
+
 
 def filter_edges_by_similarity(adj_matrix, node_attr,
                                similarity_fn, threshold=0.01,
@@ -54,8 +60,8 @@ def cosine_detection(adj_matrix, node_attr, threshold=0.01, allow_singleton=Fals
                                       allow_singleton=allow_singleton)
 
 
-@Transformers.register()
-class JaccardDetection(Transform):
+@Transform.register()
+class JaccardDetection(GraphTransform):
 
     def __init__(self, threshold=0., allow_singleton=False):
         super().__init__()
@@ -66,7 +72,7 @@ class JaccardDetection(Transform):
     def __call__(self, graph):
         assert isinstance(graph, gg.data.HomoGraph), type(graph)
         # TODO, multiple graph
-        assert not graph.multiple
+        assert not graph.is_multiple(), "NOT Supported for multiple graph"
         graph = graph.copy()
         adj_matrix = graph.adj_matrix
         node_attr = graph.node_attr
@@ -81,8 +87,8 @@ class JaccardDetection(Transform):
         return f"threshold={self.threshold}, allow_singleton={self.allow_singleton}"
 
 
-@Transformers.register()
-class CosineDetection(Transform):
+@Transform.register()
+class CosineDetection(GraphTransform):
 
     def __init__(self, threshold=0., allow_singleton=False):
         super().__init__()
@@ -93,7 +99,7 @@ class CosineDetection(Transform):
     def __call__(self, graph):
         assert isinstance(graph, gg.data.HomoGraph), type(graph)
         # TODO: multiple graph
-        assert not graph.multiple
+        assert not graph.is_multiple(), "NOT Supported for multiple graph"
         graph = graph.copy()
         adj_matrix = graph.adj_matrix
         node_attr = graph.node_attr
@@ -109,19 +115,17 @@ class CosineDetection(Transform):
         return f"threshold={self.threshold}, allow_singleton={self.allow_singleton}"
 
 
-@Transformers.register()
-class SVD(Transform):
+@Transform.register()
+class SVD(GraphTransform):
 
     def __init__(self, k=50, threshold=0.01, binaryzation=False):
         super().__init__()
-        self.k = k
-        self.threshold = threshold
-        self.binaryzation = binaryzation
+        self.collect(locals())
 
     def __call__(self, graph):
         assert isinstance(graph, gg.data.HomoGraph), type(graph)
         # TODO: multiple graph
-        assert not graph.multiple
+        assert not graph.is_multiple(), "NOT Supported for multiple graph"
         graph = graph.copy()
         adj_matrix = svd(graph.adj_matrix, k=self.k,
                          threshold=self.threshold,
@@ -129,9 +133,6 @@ class SVD(Transform):
         graph.update(adj_matrix=adj_matrix)
         return graph
 
-    def extra_repr(self):
-        return f"k={self.k}, threshold={self.threshold}, binaryzation={self.binaryzation}"
-
 
 def svd(adj_matrix, k=50, threshold=0.01, binaryzation=False):
     adj_matrix = adj_matrix.asfptype()
