@@ -1,13 +1,11 @@
 import torch
 import numpy as np
-import tensorflow as tf
 import scipy.sparse as sp
 from typing import Any, Union, Optional
 
 import graphgallery as gg
 from graphgallery import functional as gf
 
-from . import tensorflow
 from . import pytorch
 
 
@@ -20,21 +18,22 @@ def get_module(backend=None):
     Parameters
     ----------
     backend: String or BackendModule, optional.
-        'tensorflow', 'torch', TensorFlowBackend, 
-        PyTorchBackend, etc. if not specified, 
-        return the current backend module. 
+        'tensorflow', 'torch', TensorFlowBackend,
+        PyTorchBackend, etc. if not specified,
+        return the current backend module.
 
     Returns
     -------
     module:
-    - 'graphgallery.functional.tensor.tensorflow' 
+    - 'graphgallery.functional.tensor.tensorflow'
         for tensorflow backend,
     - 'graphgallery.functional.tensor.pytorch'
-        for pytorch backend    
+        for pytorch backend
     """
     backend = gg.backend(backend)
 
     if backend == "tensorflow":
+        from . import tensorflow
         return tensorflow
     else:
         return pytorch
@@ -65,15 +64,17 @@ def infer_type(x: Any) -> str:
         else:
             raise TypeError(f"Invalid type of pytorch Tensor: '{type(x)}'")
 
-    elif tensorflow.is_tensor(x):
-        if x.dtype.is_floating:
-            return gg.floatx()
-        elif x.dtype.is_integer or x.dtype.is_unsigned:
-            return gg.intx()
-        elif x.dtype.is_bool:
-            return gg.boolx()
-        else:
-            raise TypeError(f"Invalid type of tensorflow Tensor: '{type(x)}'")
+    elif gg.TF_ENABLED:
+        from . import tensorflow
+        if tensorflow.is_tensor(x):
+            if x.dtype.is_floating:
+                return gg.floatx()
+            elif x.dtype.is_integer or x.dtype.is_unsigned:
+                return gg.intx()
+            elif x.dtype.is_bool:
+                return gg.boolx()
+            else:
+                raise TypeError(f"Invalid type of tensorflow Tensor: '{type(x)}'")
 
     _x = x
     if not hasattr(_x, 'dtype'):
@@ -91,12 +92,10 @@ def infer_type(x: Any) -> str:
         raise TypeError(f"Invalid input of '{type(x).__name__}'.")
 
 
-def gather(x, index_or_mask=None):
+def gather(x, index_or_mask=None, *, backend=None):
     # TODO axis?
-    if tensorflow.is_tensor(x):
-        return tensorflow.gather(x, index_or_mask)
-    else:
-        return pytorch.gather(x, index_or_mask)
+    module = get_module(backend)
+    return module.gather(x, index_or_mask)
 
 
 def to(tensor, device_or_dtype):
@@ -148,16 +147,16 @@ def normalize_adj_tensor(adj,
     return module.normalize_adj_tensor(adj, rate=rate, fill_weight=fill_weight)
 
 
-def add_selfloops_edge(edge_index,
-                       edge_weight,
-                       num_nodes=None,
-                       fill_weight=1.0,
-                       backend=None):
+def add_selfloops_edge_tensor(edge_index,
+                              edge_weight,
+                              num_nodes=None,
+                              fill_weight=1.0,
+                              backend=None):
     module = get_module(backend)
-    return module.add_selfloops_edge(edge_index,
-                                     edge_weight,
-                                     num_nodes=num_nodes,
-                                     fill_weight=fill_weight)
+    return module.add_selfloops_edge_tensor(edge_index,
+                                            edge_weight,
+                                            num_nodes=num_nodes,
+                                            fill_weight=fill_weight)
 
 
 def normalize_edge_tensor(edge_index,
