@@ -29,11 +29,11 @@ def is_tensor(x: Any) -> bool:
 
 
 def is_sparse(x: Any) -> bool:
-    return is_tensor(x) and not is_dense(x)
+    return is_tensor(x) and x.is_sparse
 
 
 def is_dense(x: Any) -> bool:
-    return is_tensor(x) and x.layout == torch.strided
+    return is_tensor(x) and not x.is_sparse
 
 
 def astensor(x, *, dtype=None, device=None, escape=None):
@@ -44,6 +44,15 @@ def astensor(x, *, dtype=None, device=None, escape=None):
     except TypeError:
         raise TypeError(f"argument 'escape' must be a type or tuple of types.")
 
+    # update: accept `dict` instance
+    if isinstance(x, dict):
+        for k, v in x.items():
+            try:
+                x[k] = astensor(v, dtype=dtype, device=device, escape=escape)
+            except TypeError:
+                pass
+        return x
+
     if dtype is None:
         dtype = gf.infer_type(x)
 
@@ -56,13 +65,13 @@ def astensor(x, *, dtype=None, device=None, escape=None):
 
     if is_tensor(x):
         tensor = x.to(dtype)
-    elif gf.is_tensor(x, backend='tensorflow'):
-        return astensor(gf.tensoras(x),
-                        dtype=dtype,
-                        device=device,
-                        escape=escape)
+    # elif gf.is_tensor(x, backend='tensorflow'):
+    #     return astensor(gf.tensoras(x),
+    #                     dtype=dtype,
+    #                     device=device,
+    #                     escape=escape)
     elif sp.isspmatrix(x):
-        if gg.backend() == "dgl_torch":
+        if gg.backend() == "dgl":
             import dgl
             tensor = dgl.from_scipy(x, idtype=getattr(torch, gg.intx()))
         elif gg.backend() == "pyg":
