@@ -2,7 +2,6 @@ import tensorflow as tf
 import numpy as np
 import scipy.sparse as sp
 import graphgallery as gg
-import tensorflow.keras.backend as K
 
 from typing import Any
 from graphgallery import functional as gf
@@ -26,7 +25,7 @@ def data_type_dict():
 
 
 def is_sparse(x: Any) -> bool:
-    return K.is_sparse(x)
+    return tf.keras.backend.is_sparse(x)
 
 
 def is_dense(x: Any) -> bool:
@@ -46,6 +45,16 @@ def astensor(x, *, dtype=None, device=None, escape=None):
             return x
     except TypeError:
         raise TypeError(f"argument 'escape' must be a type or tuple of types.")
+
+    # update: accept `dict` instance
+    if isinstance(x, dict):
+        for k, v in x.items():
+            try:
+                x[k] = astensor(v, dtype=dtype, device=device, escape=escape)
+            except TypeError:
+                pass
+        return x
+
     if dtype is None:
         dtype = gf.infer_type(x)
     elif isinstance(dtype, tf.dtypes.DType):
@@ -68,12 +77,7 @@ def astensor(x, *, dtype=None, device=None, escape=None):
                             device=device,
                             escape=escape)
         elif sp.isspmatrix(x):
-            if gg.backend() == "dgl_tf":
-                import dgl
-                return dgl.from_scipy(x, idtype=getattr(tf,
-                                                        gg.intx())).to(device)
-            else:
-                return sparse_adj_to_sparse_tensor(x, dtype=dtype)
+            return sparse_adj_to_sparse_tensor(x, dtype=dtype)
         elif any((isinstance(x, (np.ndarray, np.matrix)), gg.is_listlike(x),
                   gg.is_scalar(x))):
             return tf.convert_to_tensor(x, dtype=dtype)
