@@ -1,15 +1,15 @@
 import torch
-from torch.nn import Module, Parameter
+from torch.nn import Module
 
 
-class SGConvolution(Module):
-    def __init__(self, order=2, **kwargs):
+class SGConv(Module):
+    def __init__(self, K=2, **kwargs):
         super().__init__()
-        self.order = order
+        self.K = K
 
     def forward(self, x, adj):
 
-        for _ in range(self.order):
+        for _ in range(self.K):
             x = torch.spmm(adj, x)
 
         return x
@@ -18,4 +18,4 @@ class SGConvolution(Module):
         pass
 
     def extra_repr(self):
-        return f"order={self.order}"
+        return f"K={self.K}"
