@@ -1,27 +1,27 @@
-import torch
+import torch.nn as nn
 from torch.nn import Module, Parameter
 
 
-class TrainableSGConvolution(Module):
+class TrainableSGConv(Module):
     def __init__(self,
-                 in_channels,
-                 out_channels,
-                 use_bias=False,
-                 order=2,
+                 in_features,
+                 out_features,
+                 bias=False,
+                 K=2,
                  cached=True,
                  **kwargs):
 
         super().__init__()
-        self.order = order
-        self.w = nn.Linear(in_channels, out_channels, bias=use_bias)
+        self.K = K
+        self.w = nn.Linear(in_features, out_features, bias=bias)
         self.cache = None
         self.cached = cached
 
     def forward(self, x, adj):
 
         if self.cache is None or not self.cached:
-            for _ in range(self.order):
-                x = torch.spmm(adj, x)
+            for _ in range(self.K):
+                x = adj.mm(x)
             self.cache = x
         else:
             x = self.cache
@@ -32,4 +32,4 @@ class TrainableSGConvolution(Module):
         self.w.reset_parameters()
 
     def __repr__(self):
-        return f"{self.__class__.__name__}({self.in_channels} -> {self.out_channels}, order={self.order})"
+        return f"{self.__class__.__name__}({self.in_features}, {self.out_features}, K={self.K})"
