@@ -47,7 +47,7 @@ class MedianAggregator(Layer):
 
         Input shape:
           tuple/list with two tensor: 2-D Tensor `x` and 3-D Tensor `neigh_x`: 
-          `[(batch_num_nodes, num_node_attrs), (batch_num_nodes, num_samples, num_node_attrs)]`.
+          `[(batch_num_nodes, num_node_attrs), (batch_num_nodes, sizes, num_node_attrs)]`.
           The former one is the node attribute matrix (Tensor) and the last is the neighbor node attribute matrix (Tensor).
 
         Output shape:
@@ -202,7 +202,7 @@ class MedianGCNAggregator(Layer):
 
         Input shape:
           tuple/list with two tensor: 2-D Tensor `x` and 3-D Tensor `neigh_x`: 
-          `[(batch_num_nodes, num_node_attrs), (batch_num_nodes, num_samples, num_node_attrs)]`.
+          `[(batch_num_nodes, num_node_attrs), (batch_num_nodes, sizes, num_node_attrs)]`.
           The former one is the node attribute matrix (Tensor) and the last is the neighbor node attribute matrix (Tensor).
 
         Output shape:
@@ -223,7 +223,7 @@ class MedianGCNAggregator(Layer):
                  bias_constraint=None,
                  **kwargs):
 
-        kwargs.pop('concat', None)  # in order to be compatible with `MeanAggregator`
+        kwargs.pop('concat', None)  # in order to be compatible with `SAGEAggregator`
         super().__init__(**kwargs)
         self.units = units
         self.use_bias = use_bias
