@@ -4,10 +4,9 @@ from torch import nn
 
 class Metric(nn.Module):
 
-    def __init__(self, name=None, dtype=None, **kwargs):
+    def __init__(self, name=None, **kwargs):
         super().__init__()
         self.name = name
-        self.dtype = dtype
         self.reset_states()
 
     def forward(self, *args, **kwargs):
@@ -18,6 +17,12 @@ class Metric(nn.Module):
 
     def reset_states(self):
         raise NotImplementedError
+        
+    def reset_state(self):
+        return self.reset_states()
 
     def result(self):
         raise NotImplementedError
+        
+    def extra_repr(self):
+        return f"name={self.name}"
