@@ -1,7 +1,6 @@
 import torch.nn as nn
 from torch import optim
 from graphgallery.nn.models import TorchKeras
-from graphgallery.nn.layers.pytorch.get_activation import get_activation
 from graphgallery.nn.layers.pytorch import PairNorm
 from graphgallery.nn.metrics.pytorch import Accuracy
 
@@ -12,31 +11,31 @@ class SGC_PN(TorchKeras):
     ICLR 2020"""
 
     def __init__(self,
-                 in_channels,
-                 out_channels,
+                 in_features,
+                 out_features,
                  hids=[],
                  acts=[],
-                 order=2,
+                 K=2,
                  norm_mode=None,
                  norm_scale=10,
                  dropout=0.6,
                  weight_decay=5e-4,
                  lr=0.005,
-                 use_bias=False):
+                 bias=False):
 
         super().__init__()
         assert not hids and not acts
-        self.linear = nn.Linear(in_channels, out_channels, bias=use_bias)
+        self.linear = nn.Linear(in_features, out_features, bias=bias)
         self.norm = PairNorm(norm_mode, norm_scale)
         self.dropout = nn.Dropout(p=dropout)
-        self.order = order
+        self.K = K
         self.compile(loss=nn.CrossEntropyLoss(),
                      optimizer=optim.Adam(self.parameters(), lr=0.01),
                      metrics=[Accuracy()])
 
     def forward(self, x, adj):
         x = self.norm(x)
-        for _ in range(self.order):
+        for _ in range(self.K):
             x = adj.mm(x)
             x = self.norm(x)
         x = self.dropout(x)
