@@ -1,6 +1,5 @@
 from .gat import GAT
 from .gcn import GCN
-from .sgc import SGC
 from .densegcn import DenseGCN
 from .gcna import GCNA
 from .chebynet import ChebyNet
@@ -12,3 +11,7 @@ from .gwnn import GWNN
 from .fastgcn import FastGCN
 from .graphsage import GraphSAGE
 from .mlp import MLP
+from .tagcn import TAGCN
+from .appnp import APPNP
+from .agnn import AGNN
+from .arma import ARMA
