@@ -1,9 +1,6 @@
-from typing import Dict, Any
 
-
-def raise_if_kwargs(kwargs: Dict[str, Any]) -> None:
+def raise_if_kwargs(kwargs):
     if kwargs:
         raise TypeError(
             f"Got an unexpected keyword argument '{next(iter(kwargs.keys()))}'"
         )
-        
\ No newline at end of file
